***************************
* File: a_chef de centre.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\4- Data\4.1 Raw Data\Second Round\csb_1er_jour\a_chef de centre.dta", replace
**************************************************
***   Ensure all variables are present and labeled.
**************************************************

cd "Source\Second Round\csb_1er_jour"
log using "a_chef de centre", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "a_chef de centre label values", replace

**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist      act_aut_6 occup_aut1 occup_aut2 temp_aut per_aut rev_aut{
	gen error01`v' = (act_aut_12 == 2 & `v'< . )
} 

foreach v of varlist     occup_aut1 occup_aut2 temp_aut per_aut rev_aut{
	gen error02`v' = ( act_aut_6  == 2 & `v'< . )
} 

**************************************************
***   Identify illegal responses
**************************************************

log using "a_chef de centre label inspect", replace
inspect
log close

**************************************************
***    Identify outliers
**************************************************

grubbs  an_chef_cs an_chef an_sante rev_aut temp_aut nb_form, level(99.99)


**************************************************
***    Identify errors to be reviewed
**************************************************
replace act_aut_6=. if error01act_aut_6==1
drop err* grubbs*

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\csb_1er_jour"
log using "a_chef de centre codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\csb_1er_jour"
save "a_chef de centre_cleaned_data.dta", replace
