***************************
* File: B_centre_sante.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use "Source\Madagascar 2006 P H\4- Data\4.1 Raw Data\Second Round\csb_1er_jour\B_centre_sante.dta"



**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\csb_1er_jour"
log using "B_centre_sante", replace
codebook, compact
log close

label var  constr "derniere construction salle"


**************************************************
***   Ensure response value labels are correct.
**************************************************
label save using "B_centre_sante label values", replace


**************************************************
***   Recode missing values
***************************************************

*    DECODE MISSING VALUES
# d ;
qui mvdecode constr , mv(
5=.d);
# d cr;

**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist     trs_bank tps_bank {
	gen error01`v' = (bank == 1 & `v'< . )
}
 
foreach v of varlist     trs_post tps_post {
	gen error01`v' = (post == 1 & `v'< . )
}

foreach v of varlist     trs_taxi tps_taxi {
	gen error01`v' = (taxi == 1 & `v'< . )
}

foreach v of varlist     trs_gend tps_gend {
	gen error01`v' = (gend == 1 & `v'< . )
}

foreach v of varlist   trs_march tps_march{
	gen error01`v' = (marche == 1 & `v'< . )
}


**************************************************
***   Identify illegal responses
**************************************************

log using "B_centre_sante label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

grubbs  an_cs tps*, level(99.99)

**************************************************
***   Reviewing errors and computing responses
**************************************************
replace marche=2 if code_cs== 1031312
drop err* grubbs*

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\csb_1er_jour"
log using "B_centre_sante codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\csb_1er_jour"
save B_centre_sante_cleaned_data.dta, replace
