***************************
* File: c_personnel.do 
* Questionnaire type: Health Facility
* Country: Madagascar
*****************************

version 10.1
cd "Source\Madagascar 2006 P H\"
capture clear
capture log close
clear
set mem 700m
set more off


use"Source\4- Data\4.1 Raw Data\Second Round\csb_1er_jour\C_personnel.dta"



**************************************************
***   Ensure all variables are present and labeled.
**************************************************
cd "Source\Second Round\csb_1er_jour"
log using "C_personnel", replace
codebook, compact
log close

**************************************************
***    Ensure response value labels are correct.
**************************************************
label save using "C_personnel label values", replace

**************************************************
***    Unique identifiers: ID
**************************************************
egen ID=concat( code_cs cod_pers)
destring ID, replace
order code_cs cod_pers ID
label var ID "identifiant unique"

**************************************************
***   Recode missing values
***************************************************

*    DECODE MISSING VALUES
# d ;
qui mvdecode abs_auto , mv(
6=.d);


qui mvdecode abs_n_auto , mv(
7=.d);

qui mvdecode  rsn_abs, mv(
10=.d);

qui mvdecode   fich_pres, mv(
4=.d);

qui mvdecode  abs_rest, mv(
999=.d);
# d cr;


**************************************************
***   Identify skip patterns
**************************************************
* Recode missing values to Stata missing values, for tests and data inspection.
quietly mvdecode _all,mv (-666 = .d \ -777 = .n \ -888 = .l \ -999 = .r) 

foreach v of varlist  ver_physique fich_pres {
	gen error01`v' = (  present== 2 & `v'< . )
}


foreach v of varlist   fonct_off  malade jour_mal heure1 min1 heure2 min2 abs_auto  doc_abs abs_n_auto {
	gen error02`v' = (  rsn_abs== 1 & `v'< . )
}

 
foreach v of varlist  typ_mission malade jour_mal heure1 min1 heure2 min2 abs_auto  doc_abs abs_n_auto {
	gen error03`v' = (rsn_abs== 2 & `v'< . )
}

foreach v of varlist    typ_mission fonct_off   heure1 min1 heure2 min2 abs_auto  doc_abs  abs_n_auto{
	gen error04`v' = (rsn_abs== 4 & `v'< . )
}

foreach v of varlist  typ_mission fonct_off  malade jour_mal abs_auto  doc_abs  abs_n_auto{
	gen error05`v' = (rsn_abs== 5 & `v'< . )
}

foreach v of varlist typ_mission fonct_off  malade jour_mal heure1 min1 heure2 min2  abs_n_auto{
	gen error06`v' = (rsn_abs== 6 & `v'< . )
}


**************************************************
***    Identify illegal responses
**************************************************

log using "C_personnel  label inspect", replace
inspect
log close

**************************************************
***   Identify outliers
**************************************************

grubbs transfere jour_mal heure1 min1 heure2 min2 jour_abs abs_rest, level(99.99)

**************************************************
***   11: Identify errors to be reviewed
**************************************************
replace fich_pres=.   if error01fich_pres== 1

**************************************************
***   Reviewing errors and computing responses
**************************************************

drop err* grubbs*

**************************************************
*** FINAL   : Delivrables
**************************************************

*Codebook
cd "Source\4- Data\4.3. Clean Data\4.3.3. Data Code Book\Second Round\csb_1er_jour"
log using "C_personnel codebook", replace
codebook, compact
log close

*Save cleaned data
cd "Source\4- Data\4.3. Clean Data\4.3.1. Final Data\Second Round\csb_1er_jour"
save C_personnel_cleaned_data.dta, replace
